@@ -1,4 +1,4 @@
-import React, { useState, useContext } from "react";
+import React, { useContext } from "react";
 import { Link, useParams } from "react-router-dom";
 import {
   TLink,
@@ -9,11 +9,13 @@ import {
   Delete,
   CopyText,
   HasActionIcon,
+  HasToManyIcon,
+  useToggle,
 } from "./Util";
 import { Results } from "./Results";
 import { getPartsForQuery, getRelUrlForQuery } from "./Query";
 import { ShowTooltip, HideTooltip } from "./Tooltip";
-import "./App.css";
+import "./App.scss";
 
 function FilterValue(props) {
   const { lookupType, onChange, value, field } = props;
@@ -22,16 +24,18 @@ function FilterValue(props) {
   const hideTooltip = useContext(HideTooltip);
   const helpText = {
     date: [
-      "Date filter values can be a literal value e.g. '2020-12-21' or 'today' or a series of clauses applied in order from today.",
+      "Date filter values consist of a series of clauses applied in order left to right starting with a value of `today`.",
       "e.g. 'day=1 month+1 tuesday+2' which means move to the 1st of this month, then move forward a month, then move forward to the second Tuesday.",
-      "You can use 'year', 'month' or 'day' with '+', '-', or '=' to add remove or replace the given quantity.",
+      "Possible clauses include 'today', 'now' and literal date values in a variety of formats e.g. '2020-12-21'.",
+      "Or you can use 'year', 'month', 'week' or 'day' with '+', '-', or '=' to add remove or replace the given quantity.",
       "Or you can use a weekday name with '+' or '-' to get the n-th next or previous (including today) instance of that day.",
       "Bear in mind that 'day=1 month+1' may produce a different result from 'month+1 day=1', for example on Jan 31st.",
     ],
     datetime: [
-      "Datetime filter values can be a literal value e.g. '2020-12-21 14:56' or 'now' or a series of clauses applied in order from now.",
+      "Datetime filter consist of a series of clauses applied in order left to right starting with a value of `now`.",
       "e.g. 'day=1 month+1 tuesday+2' which means move to the 1st of this month, then move forward a month, then move forward to the second Tuesday.",
-      "You can use 'year', 'month', 'day', 'hour', 'minute' or 'second' with '+', '-', or '=' to add remove or replace the given quantity.",
+      "Possible clauses include 'today', 'now' and literal date and time values in a variety of formats e.g. '2020-12-21 14:56'.",
+      "Or you can use 'year', 'month', 'week', 'day', 'hour', 'minute' or 'second' with '+', '-', or '=' to add remove or replace the given quantity.",
       "Or you can use a weekday name with '+' or '-' to get the n-th next or previous (including today) instance of that day.",
       "Bear in mind that 'day=1 month+1' may produce a different result from 'month+1 day=1', for example on Jan 31st.",
     ],
@@ -168,22 +172,27 @@ function Filter(props) {
 }
 
 function Filters(props) {
-  const { query, filterErrors, parsedFilterValues } = props;
+  const { query, filterErrors, parsedFilterValues, filters } = props;
+  const [toggled, toggleLink] = useToggle(true);
+  if (!filters.length) return "";
   return (
     <form className="Filters" onSubmit={(e) => e.preventDefault()}>
-      <table>
-        <tbody>
-          {props.filters.map((filter, index) => (
-            <Filter
-              {...{ query, index }}
-              {...filter}
-              key={index}
-              errorMessage={filterErrors[index]}
-              parsed={parsedFilterValues[index]}
-            />
-          ))}
-        </tbody>
-      </table>
+      <div className="FiltersToggle">{toggleLink}</div>
+      {toggled && (
+        <table>
+          <tbody>
+            {filters.map((filter, index) => (
+              <Filter
+                {...{ query, index }}
+                {...filter}
+                key={index}
+                errorMessage={filterErrors[index]}
+                parsed={parsedFilterValues[index]}
+              />
+            ))}
+          </tbody>
+        </table>
+      )}
     </form>
   );
 }
@@ -191,7 +200,8 @@ function Filters(props) {
 function Field(props) {
   const { query, path, modelField } = props;
   const type = query.getType(modelField);
-  const [toggled, setToggled] = useState(false);
+  const [toggled, toggleLink] = useToggle();
+
   return (
     <>
       <tr className="Field">
@@ -205,16 +215,7 @@ function Field(props) {
         </td>
 
         {/* expand */}
-        <td>
-          {modelField.model && (
-            <SLink
-              className="ToggleLink"
-              onClick={() => setToggled((toggled) => !toggled)}
-            >
-              {toggled ? "remove" : "add"}
-            </SLink>
-          )}
-        </td>
+        <td>{modelField.model && toggleLink}</td>
 
         {/* name */}
         <td className={`FieldName ${query.getFieldClass(modelField)}`}>
@@ -231,7 +232,13 @@ function Field(props) {
               />
             </TLink>
           ) : (
-            modelField.prettyName + (modelField.toMany ? " \u21f6" : "")
+            <>
+              {modelField.prettyName}
+              <HasToManyIcon
+                modelField={modelField}
+                message="Traversing 'To Many' links may add multiple lines per result."
+              />
+            </>
           )}
         </td>
       </tr>
@@ -241,7 +248,7 @@ function Field(props) {
         <tr>
           <td></td>
           <td colSpan="2">
-            <AllFields {...{ query, path }} model={modelField.model} />
+            <FieldGroup {...{ query, path }} model={modelField.model} />
           </td>
         </tr>
       )}
@@ -249,11 +256,11 @@ function Field(props) {
   );
 }
 
-function AllFields(props) {
+function FieldGroup(props) {
   const { query, model, path } = props;
   const modelFields = query.getModelFields(model);
   return (
-    <table className="AllFields">
+    <table className="FieldGroup">
       <tbody>
         {modelFields.sortedFields.map((fieldName) => {
           const modelField = modelFields.fields[fieldName];
@@ -270,17 +277,35 @@ function AllFields(props) {
   );
 }
 
+const SEP = ".";
+
 function ModelSelector(props) {
   const { query, sortedModels, model } = props;
+
+  const modelsByAppLabel = sortedModels.reduce((a, x) => {
+    const [appLabel] = x.split(SEP);
+
+    return {
+      ...a,
+      [appLabel]: [...(a[appLabel] || []), x],
+    };
+  }, {});
+
   return (
     <select
       className="ModelSelector"
       onChange={(e) => query.setModel(e.target.value)}
       value={model}
     >
-      {sortedModels.map((model) => (
-        <option key={model}>{model}</option>
-      ))}
+      {Object.entries(modelsByAppLabel).map(([byAppLabel, models]) => {
+        return (
+          <optgroup label={byAppLabel}>
+            {models.map((model) => (
+              <option key={model}>{model}</option>
+            ))}
+          </optgroup>
+        );
+      })}
     </select>
   );
 }
@@ -316,7 +341,9 @@ function QueryPage(props) {
     results = (
       <Results {...{ query, rows, cols, body, overlay, formatHints }} />
     );
-  else results = <h2>No fields selected</h2>;
+  else results = <h1>No fields selected</h1>;
+
+  const [fieldsToggled, fieldsToggleLink] = useToggle(true);
 
   return (
     <div className="QueryPage">
@@ -348,9 +375,12 @@ function QueryPage(props) {
       </p>
       <div className="MainSpace">
         <div className="FieldsList">
-          <div className="Scroller">
-            <AllFields {...{ query, model }} path={[]} />
-          </div>
+          <div className="FieldsToggle">{fieldsToggleLink}</div>
+          {fieldsToggled && (
+            <div className="Scroller">
+              <FieldGroup {...{ query, model }} path={[]} />
+            </div>
+          )}
         </div>
         {results}
         <div />
