@@ -1,8 +1,8 @@
-from django.contrib.postgres.fields import ArrayField  # pragma: postgres
-from django.db import models  # pragma: postgres
+from django.contrib.postgres.fields import ArrayField
+from django.db import models
 
 
-class ArrayModel(models.Model):  # pragma: postgres
+class ArrayModel(models.Model):
     char_array_field = ArrayField(null=True, base_field=models.CharField(max_length=32))
     int_array_field = ArrayField(null=True, base_field=models.IntegerField())
     char_choice_array_field = ArrayField(
