@@ -10,10 +10,10 @@ DATABASE_CONFIG = dj_database_url.config(
 POSTGRES = "postgresql" in DATABASE_CONFIG["ENGINE"]
 SQLITE = "sqlite" in DATABASE_CONFIG["ENGINE"]
 
-if POSTGRES:  # pragma: postgres
+if POSTGRES:
     JSON_FIELD_SUPPORT = django.VERSION >= (2, 1)
     ARRAY_FIELD_SUPPORT = True
-else:  # pragma: not postgres
+else:
     JSON_FIELD_SUPPORT = django.VERSION >= (3, 1)
     ARRAY_FIELD_SUPPORT = False
 
@@ -29,7 +29,7 @@ INSTALLED_APPS = [
 
 if JSON_FIELD_SUPPORT:  # pragma: no branch
     INSTALLED_APPS.append("tests.json")
-if ARRAY_FIELD_SUPPORT:  # pragma: postgres
+if ARRAY_FIELD_SUPPORT:
     INSTALLED_APPS.append("tests.array")
 
 settings.configure(
@@ -68,7 +68,24 @@ settings.configure(
 
 
 @pytest.fixture
-def req(rf, admin_user):
-    req = rf.get("/")
-    req.user = admin_user
-    return req
+def ddb_request(rf):
+    from data_browser.views import _add_request_info
+
+    request = rf.get("/")
+    _add_request_info(request)
+    return request
+
+
+@pytest.fixture
+def admin_ddb_request(ddb_request, admin_user):
+    ddb_request.user = admin_user
+    return ddb_request
+
+
+@pytest.fixture
+def mock_admin_get_queryset(mocker):
+    from data_browser.orm_admin import admin_get_queryset
+
+    return mocker.patch(
+        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
+    )
