@@ -9,12 +9,12 @@ from data_browser.query import BoundQuery, Query
 
 from .conftest import JSON_FIELD_SUPPORT, SQLITE
 
-""" Howto enable SQLite JSON support https://code.djangoproject.com/wiki/JSON1Extension """
+# Howto enable SQLite JSON support https://code.djangoproject.com/wiki/JSON1Extension
 
 
 if JSON_FIELD_SUPPORT:
     from .json.models import JsonModel
-else:  # pragma: no cover
+else:
     pytestmark = pytest.mark.skip("Needs JSONField support")
 
 
@@ -33,14 +33,14 @@ def with_json(db):
 
 
 @pytest.fixture
-def get_results_flat(with_json, req):
-    def helper(fields, query=None):
-        query = query or []
-
-        orm_models = get_models(req)
-        query = Query.from_request("json.JsonModel", fields, query)
+def get_results_flat(with_json, admin_ddb_request):
+    def helper(*fields, **filters):
+        orm_models = get_models(admin_ddb_request)
+        query = Query.from_request(
+            "json.JsonModel", ",".join(fields), list(filters.items())
+        )
         bound_query = BoundQuery.bind(query, orm_models)
-        data = get_results(req, bound_query, orm_models, False)
+        data = get_results(admin_ddb_request, bound_query, orm_models, False)
 
         for f in bound_query.filters:
             if f.err_message:
@@ -67,7 +67,7 @@ def test_get_string_sub_field(get_results_flat):
     SQLITE and django.VERSION[:3] == (3, 1, 3),
     reason="https://code.djangoproject.com/ticket/32203",
 )
-def test_get_number_sub_field(get_results_flat):  # pragma: not sqlite
+def test_get_number_sub_field(get_results_flat):
     JsonModel.objects.create(json_field={"position": 1})
     assert get_results_flat("json_field__position") == [{"json_field__position": 1}]
 
@@ -76,7 +76,7 @@ def test_get_number_sub_field(get_results_flat):  # pragma: not sqlite
     SQLITE and django.VERSION[:3] == (3, 1, 3),
     reason="https://code.djangoproject.com/ticket/32203",
 )
-def test_get_boolean_sub_field(get_results_flat):  # pragma: not sqlite
+def test_get_boolean_sub_field(get_results_flat):
     JsonModel.objects.create(json_field={"bool": True})
     assert get_results_flat("json_field__bool") == [{"json_field__bool": True}]
 
@@ -85,11 +85,11 @@ def test_get_boolean_sub_field(get_results_flat):  # pragma: not sqlite
     SQLITE and django.VERSION[:3] == (3, 1, 3),
     reason="https://code.djangoproject.com/ticket/32203",
 )
-def test_sub_field_is_null(get_results_flat):  # pragma: not sqlite
+def test_sub_field_is_null(get_results_flat):
     JsonModel.objects.create(json_field={"position": 1, "hello": "world"})
     JsonModel.objects.create(json_field={"position": 2, "hello": None})
     JsonModel.objects.create(json_field={"position": 3, "goodbye": "world"})
-    assert get_results_flat("json_field__hello__is_null,json_field__position+1") == [
+    assert get_results_flat("json_field__hello__is_null", "json_field__position+1") == [
         {"json_field__hello__is_null": "NotNull", "json_field__position": 1},
         {"json_field__hello__is_null": "IsNull", "json_field__position": 2},
         {"json_field__hello__is_null": "IsNull", "json_field__position": 3},
@@ -97,25 +97,25 @@ def test_sub_field_is_null(get_results_flat):  # pragma: not sqlite
 
     # __is_null=
     assert get_results_flat(
-        "json_field__position+1", [("json_field__hello__is_null", "NotNull")]
+        "json_field__position+1", json_field__hello__is_null="NotNull"
     ) == [{"json_field__position": 1}]
     assert get_results_flat(
-        "json_field__position+1", [("json_field__hello__is_null", "IsNull")]
+        "json_field__position+1", json_field__hello__is_null="IsNull"
     ) == [{"json_field__position": 2}, {"json_field__position": 3}]
 
     # __is_null__equals=
     assert get_results_flat(
-        "json_field__position+1", [("json_field__hello__is_null__equals", "NotNull")]
+        "json_field__position+1", json_field__hello__is_null__equals="NotNull"
     ) == [{"json_field__position": 1}]
     assert get_results_flat(
-        "json_field__position+1", [("json_field__hello__is_null__equals", "IsNull")]
+        "json_field__position+1", json_field__hello__is_null__equals="IsNull"
     ) == [{"json_field__position": 2}, {"json_field__position": 3}]
 
 
 def test_filter_sub_field(get_results_flat):
     JsonModel.objects.create(json_field={"hello": "world"})
     JsonModel.objects.create(json_field={"hello": "universe"})
-    assert get_results_flat("json_field", [("json_field__hello__equals", "world")]) == [
+    assert get_results_flat("json_field", json_field__hello__equals="world") == [
         {"json_field": '{"hello": "world"}'}
     ]
 
@@ -124,46 +124,43 @@ def test_filter_field_value(get_results_flat):
     JsonModel.objects.create(json_field={"goodbye": "universe"})
     assert get_results_flat("json_field") == [{"json_field": '{"goodbye": "universe"}'}]
     assert (
-        get_results_flat(
-            "json_field", [("json_field__field_equals", 'goodbye|"world"')]
-        )
-        == []
+        get_results_flat("json_field", json_field__field_equals='goodbye|"world"') == []
     )
 
 
 def test_filter_field_value_no_seperator(get_results_flat):
     JsonModel.objects.create(json_field={"goodbye": "universe"})
     assert get_results_flat(
-        "json_field", [("json_field__field_equals", 'goodbye"world"')]
+        "json_field", json_field__field_equals='goodbye"world"'
     ) == [{"json_field": '{"goodbye": "universe"}'}]
 
 
 def test_filter_field_value_no_field(get_results_flat):
     JsonModel.objects.create(json_field={"goodbye": "universe"})
-    assert get_results_flat(
-        "json_field", [("json_field__field_equals", '|"world"')]
-    ) == [{"json_field": '{"goodbye": "universe"}'}]
+    assert get_results_flat("json_field", json_field__field_equals='|"world"') == [
+        {"json_field": '{"goodbye": "universe"}'}
+    ]
 
 
 def test_filter_field_value_list(get_results_flat):
     JsonModel.objects.create(json_field={"goodbye": ["world"]})
     JsonModel.objects.create(json_field={"goodbye": ["universe"]})
     assert get_results_flat(
-        "json_field", [("json_field__field_equals", 'goodbye|["world"]')]
+        "json_field", json_field__field_equals='goodbye|["world"]'
     ) == [{"json_field": '{"goodbye": ["world"]}'}]
 
 
 def test_filter_field_value_bad_json(get_results_flat):
     JsonModel.objects.create(json_field={"goodbye": "universe"})
-    assert get_results_flat(
-        "json_field", [("json_field__field_equals", "goodbye|world")]
-    ) == [{"json_field": '{"goodbye": "universe"}'}]
+    assert get_results_flat("json_field", json_field__field_equals="goodbye|world") == [
+        {"json_field": '{"goodbye": "universe"}'}
+    ]
 
 
 def test_filter_has_key(get_results_flat):
     JsonModel.objects.create(json_field={"hello": "world"})
     JsonModel.objects.create(json_field={"goodbye": "world"})
-    assert get_results_flat("json_field", [("json_field__has_key", "hello")]) == [
+    assert get_results_flat("json_field", json_field__has_key="hello") == [
         {"json_field": '{"hello": "world"}'}
     ]
 
@@ -171,14 +168,15 @@ def test_filter_has_key(get_results_flat):
 def test_filter_equals(get_results_flat):
     JsonModel.objects.create(json_field={"hello": "world"})
     JsonModel.objects.create(json_field={"goodbye": "world"})
-    assert get_results_flat(
-        "json_field", [("json_field__equals", '{"hello": "world"}')]
-    ) == [{"json_field": '{"hello": "world"}'}]
+    assert get_results_flat("json_field", json_field__equals='{"hello": "world"}') == [
+        {"json_field": '{"hello": "world"}'}
+    ]
 
 
 def test_filter_equals_bad_json(get_results_flat):
     JsonModel.objects.create(json_field={"hello": "world"})
     JsonModel.objects.create(json_field={"goodbye": "world"})
-    assert get_results_flat(
-        "json_field-1", [("json_field__equals", '{"hello": "world"')]
-    ) == [{"json_field": '{"hello": "world"}'}, {"json_field": '{"goodbye": "world"}'}]
+    assert get_results_flat("json_field-1", json_field__equals='{"hello": "world"') == [
+        {"json_field": '{"hello": "world"}'},
+        {"json_field": '{"goodbye": "world"}'},
+    ]
